@@ -10,7 +10,9 @@ import tkinter as tk
 
 class RightClickMenu(tk.Menu):
     """Context menu or right click menu popup"""
-    def __init__(self, parent, menu_items, callback=None, bg='white', fg='black', abg='blue', afg='white'):
+
+    def __init__(self, parent, menu_items, callback=None, bg='white', fg='black', abg='blue', afg='white',
+                 bind_left_click=False, bind_right_click=True):
         """initialize
         Args:
             parent: tkinter widget to show this menu when right clicked
@@ -22,6 +24,8 @@ class RightClickMenu(tk.Menu):
             fg: text color
             abg: background color on mouse hover
             afg: text color on mouse hover
+            bind_left_click: if true will bind left mouse click
+            bind_right_click: if true will bind right mouse click
 
         Example:
             right_click_map = {'say hi': lambda x: print(x),  # x = 'say hi'
@@ -44,20 +48,41 @@ class RightClickMenu(tk.Menu):
             else:
                 self.add_command(label=f' {option}', command=lambda x=option: self.context_menu_handler(x))
 
-        parent.bind("<Button-3>", self.popup, add='+')
-        parent.bind("<Button-2>", self.popup, add='+')
-
         self.parent = parent
 
-    def popup(self, event):
+        # prevent random selection if menu shows under mouse 
+        self.pressflag = False
+
+        def onpress(event):
+            self.pressflag = True
+
+        def onrelease(event):
+            # diable mouse release action if no mouse press
+            if not self.pressflag:
+                return 'break'
+            else:
+                self.pressflag = False
+
+        trigger_buttons = []
+        if bind_left_click:
+            trigger_buttons.append(1)
+        if bind_right_click:
+            trigger_buttons += [2, 3]
+
+        for i in trigger_buttons:
+            if i == 1 and parent.winfo_class() == 'Button':
+                parent['command'] = self.popup
+                continue
+            parent.bind(f"<Button-{i}>", self.popup, add='+')
+            self.bind(f'<{i}>', onpress, add='+')
+            self.bind(f'<ButtonRelease-{i}>', onrelease, add='+')
+
+    def popup(self, event=None):
         """show right click menu"""
-        # make sure popup menu will show only if mouse ontop of parent widget or its children
-        # to fix the problem of displaying menu on different widget than parent.
-        # this could be happen if right click on other widget while menu is shown
-        x, y = event.x_root, event.y_root
-        widget = self.winfo_containing(x, y)
-        if widget == self.parent or widget in self.parent.winfo_children():
-            self.tk_popup(x, y)
+        # x, y = event.x_root, event.y_root
+        x = self.parent.winfo_pointerx()
+        y = self.parent.winfo_pointery()
+        self.tk_popup(x, y)
 
     def context_menu_handler(self, option):
         """handle selected option
